@@ -10,7 +10,7 @@ use File::Spec; #not really needed because File::Copy already gets it, but for g
 require Exporter;
 our @ISA = qw(Exporter);
 our @EXPORT_OK = qw(fcopy rcopy dircopy fmove rmove dirmove pathmk pathrm pathempty pathrmdir);
-our $VERSION = '0.18';
+our $VERSION = '0.25';
 
 our $MaxDepth = 0;
 our $KeepMode = 1;
@@ -23,22 +23,25 @@ our $ForcePth = 0;
 our $CopyLoop = 0;
 our $RMTrgFil = 0;
 our $RMTrgDir = 0;
+our $CondCopy = {};
 
 my $samecheck = sub {
+   return if $^O eq 'MSWin32'; # need better way to check for this on winders...
+
    my $one = '';
    if($PFSCheck) {
-      $one = join '-', ( stat $_[0] )[0,1] || '';
-     my $two = join '-', ( stat $_[1] )[0,1] || '';
+      $one    = join( '-', ( stat $_[0] )[0,1] ) || '';
+      my $two = join( '-', ( stat $_[1] )[0,1] ) || '';
       croak "$_[0] and $_[1] are identical" if $one eq $two && $one;
    }
    if(-d $_[0] && !$CopyLoop) {
-      $one = join '-', ( stat $_[0] )[0,1] if !$one;
+      $one    = join( '-', ( stat $_[0] )[0,1] ) if !$one;
       my $abs = File::Spec->rel2abs($_[1]);
       my @pth = File::Spec->splitdir( $abs );
       while(@pth) {
          my $cur = File::Spec->catdir(@pth);
          last if !$cur; # probably not necessary, but nice to have just in case :)
-         my $two = join '-', ( stat $cur )[0,1] || '';
+         my $two = join( '-', ( stat $cur )[0,1] ) || '';
          croak "Caught Deep Recursion Condition: $_[0] contains $_[1]" if $one eq $two && $one;
          pop @pth;
       }
@@ -67,6 +70,20 @@ my $move = sub {
   return wantarray ? @x : $x[0];
 };
 
+my $ok_todo_asper_condcopy = sub {
+    my $org = shift;
+    my $copy = 1;
+    if(exists $CondCopy->{$org}) {
+        if($CondCopy->{$org}{'md5'}) {
+
+        }
+        if($copy) {
+
+        }
+    }
+    return $copy;
+};
+
 sub fcopy { 
    $samecheck->(@_);
    if($RMTrgFil && (-d $_[1] || -e $_[1]) ) {
@@ -91,19 +108,26 @@ sub fcopy {
       symlink readlink(shift()), shift() or return;
    } else {  
       copy(@_) or return;
-      chmod scalar((stat($_[0]))[2]), $_[1] if $KeepMode;
+
+      my @base_file = File::Spec->splitpath($_[0]);
+      my $mode_trg = -d $_[1] ? File::Spec->catfile($_[1], $base_file[ $#base_file ]) : $_[1];
+
+      chmod scalar((stat($_[0]))[2]), $mode_trg if $KeepMode;
    }
    return wantarray ? (1,0,0) : 1; # use 0's incase they do math on them and in case rcopy() is called in list context = no uninit val warnings
 }
 
-sub rcopy { -d $_[0] ? dircopy(@_) : fcopy(@_) }
+sub rcopy { 
+    -d $_[0] || substr( $_[0], ( 1 * -1), 1) eq '*' ? dircopy(@_) 
+                                                    : fcopy(@_); 
+}
 
 sub dircopy {
    if($RMTrgDir && -d $_[1]) {
       if($RMTrgDir == 1) {
-         pathrmdir $_[1] or carp "\$RMTrgDir failed: $!";
+         pathrmdir($_[1]) or carp "\$RMTrgDir failed: $!";
       } else {
-         pathrmdir $_[1] or return;
+         pathrmdir($_[1]) or return;
       }
    }
    my $globstar = 0;
@@ -128,9 +152,9 @@ sub dircopy {
       }
    }
    my $baseend = $_one;
-   my $level = 0;
-   my $filen = 0;
-   my $dirn = 0;
+   my $level   = 0;
+   my $filen   = 0;
+   my $dirn    = 0;
 
    my $recurs; #must be my()ed before sub {} since it calls itself
    $recurs =  sub {
@@ -149,22 +173,27 @@ sub dircopy {
       my @files = grep( $_ ne '.' && $_ ne '..', readdir($pth_dh));
       closedir $pth_dh;
 
-      for(@files) {
-         my $org = File::Spec->catfile($str, $_);
-         my $new = File::Spec->catfile($end, $_);
-         if(-l $org && $CopyLink) {
-            symlink readlink($org), $new or return;
-         } elsif(-d $org) {
-            $recurs->($org,$new,$buf) if defined $buf;
-            $recurs->($org,$new) if !defined $buf;
-            $filen++;
-            $dirn++;
-         } else {
-            copy($org,$new,$buf) or return if defined $buf;
-            copy($org,$new) or return if !defined $buf;
-            chmod scalar((stat($org))[2]), $new if $KeepMode;
-            $filen++;
-         }
+      for my $file (@files) {
+          my ($file_ut) = $file =~ m{ (.*) }xms;
+          my $org = File::Spec->catfile($str, $file_ut);
+          my $new = File::Spec->catfile($end, $file_ut);
+          if(-l $org && $CopyLink) {
+              symlink readlink($org), $new or return;
+          } 
+          elsif(-d $org) {
+              $recurs->($org,$new,$buf) if defined $buf;
+              $recurs->($org,$new) if !defined $buf;
+              $filen++;
+              $dirn++;
+          } 
+          else {
+              if($ok_todo_asper_condcopy->($org)) {
+                  fcopy($org,$new,$buf) or return if defined $buf;
+                  fcopy($org,$new) or return if !defined $buf;
+                  chmod scalar((stat($org))[2]), $new if $KeepMode;
+                  $filen++;
+              }
+          }
       }
       1;
    };
@@ -175,7 +204,13 @@ sub dircopy {
 
 sub fmove { $move->(1, @_) } 
 
-sub rmove { -d $_[0] ? dirmove(@_) : fmove(@_) }
+sub rmove { 
+    my $_zero = shift;
+    $_zero = substr( $_zero, 0, ( length( $_zero ) - 1 ) )
+        if substr( $_[0], ( 1 * -1), 1) eq '*';
+
+    -d $_zero ? dirmove($_zero, @_) : fmove($_zero, @_);
+}
 
 sub dirmove { $move->(0, @_) }
 
@@ -200,8 +235,9 @@ sub pathempty {
    my $pth = shift; 
    return 2 if !-d $pth;
    opendir(my $pth_dh, $pth) or return;
-   for(grep !/^\.+$/, readdir($pth_dh)) {
-      my $flpth = File::Spec->catdir($pth, $_);
+   for my $name (grep !/^\.+$/, readdir($pth_dh)) {
+      my ($name_ut) = $name =~ m{ (.*) }xms;
+      my $flpth = File::Spec->catdir($pth, $name_ut);
       if(-d $flpth) {
          pathrmdir($flpth) or return;
       } else {
@@ -425,11 +461,11 @@ This can be done by setting $File::Copy::Recursive::RMTrgFil or $File::Copy::Rec
 
 2 = return if removal fails
 
-    $File::Copy::Recursive::RMTrgFil = 1;
+    local $File::Copy::Recursive::RMTrgFil = 1;
     fcopy($orig, $target) or die $!;
     # if it fails it does warn() and keeps going
 
-    $File::Copy::Recursive::RMTrgDir = 2;
+    local $File::Copy::Recursive::RMTrgDir = 2;
     dircopy($orig, $target) or die $!;
     # if it fails it does your "or die"
 
@@ -446,6 +482,9 @@ By default dircopy($dir1,$dir2) will put $dir1's contents right into $dir2 wheth
 
 You can make dircopy() emulate cp -rf by setting $File::Copy::Recursive::CPRFComp to true.
 
+NOTE: This only emulates -f in the sense that it does not prompt. It does not remove the target file or directory if it exists.
+If you need to do that then use the variables $RMTrgFil and $RMTrgDir described in "Removing existing target file or directory before copying" above.
+
 That means that if $dir2 exists it puts the contents into $dir2/$dir1 instead of $dir2 just like cp -rf.
 If $dir2 does not exist then the contents go into $dir2 like normal (also like cp -rf)
 
@@ -471,7 +510,7 @@ You can also specify a star for cp -rf glob type behavior:
     # if bar does not exist the result is bar/file
     # if bar does exist the result is bar/file
 
-NOTE: The '*' is only like cp -rf foo/* and *DOES NOT EXPAND PARTIAL DIRECTORY NAMES LIKE YOUR SHELL DOES* (IE not like rp -rf fo* to copy foo/*)
+NOTE: The '*' is only like cp -rf foo/* and *DOES NOT EXPAND PARTIAL DIRECTORY NAMES LIKE YOUR SHELL DOES* (IE not like cp -rf fo* to copy foo/*)
 
 =head2 Allowing Copy Loops
 
@@ -485,6 +524,9 @@ This is false by default so that a check is done to see if the source directory
 
 If you ever find a situation where $CopyLoop = 1 is desirable let me know (IE its a bad bad idea but is there if you want it)
 
+(Note: On Windows this was necessary since it uses stat() to detemine samedness and stat() is essencially useless for this on Windows. 
+The test is now simply skipped on Windows but I'd rather have an actual reliable check if anyone in Microsoft land would care to share)
+
 =head1 SEE ALSO
 
 L<File::Copy> L<File::Spec>
